@@ -110,6 +110,8 @@ export default {
     'ブラウザで Qwen Code のドキュメントを開く',
   'Configuration not available.': '設定が利用できません',
   'change the auth method': '認証方式を変更',
+  'Configure authentication information for login':
+    'ログイン用の認証情報を設定',
   'Copy the last result or code snippet to clipboard':
     '最後の結果またはコードスニペットをクリップボードにコピー',
 
@@ -326,6 +328,8 @@ export default {
   'List active extensions': '有効な拡張機能を一覧表示',
   'Update extensions. Usage: update <extension-names>|--all':
     '拡張機能を更新。使い方: update <拡張機能名>|--all',
+  'You are installing an extension from {{originSource}}. Some features may not work perfectly with Qwen Code.':
+    '{{originSource}} から拡張機能をインストールしています。一部の機能は Qwen Code で完全に動作しない可能性があります。',
   'manage IDE integration': 'IDE連携を管理',
   'check status of IDE integration': 'IDE連携の状態を確認',
   'install required IDE companion for {{ideName}}':
@@ -677,6 +681,11 @@ export default {
   'Terms of Services and Privacy Notice for Qwen Code':
     'Qwen Code の利用規約とプライバシー通知',
   'Qwen OAuth': 'Qwen OAuth',
+  'Login with QwenChat account to use daily free quota.':
+    'QwenChatアカウントでログインして、毎日の無料クォータをご利用ください。',
+  'API-KEY': 'API-KEY',
+  'Use coding plan credentials or your own api-keys/providers.':
+    'Coding Planの認証情報またはご自身のAPIキー/プロバイダーをご利用ください。',
   OpenAI: 'OpenAI',
   'Failed to login. Message: {{message}}':
     'ログインに失敗しました。メッセージ: {{message}}',
@@ -744,9 +753,6 @@ export default {
   'Press Ctrl+D again to exit.': 'Ctrl+D をもう一度押すと終了します',
   'Press Esc again to clear.': 'Esc をもう一度押すとクリアします',
   // MCP Status
-  'Please view MCP documentation in your browser:':
-    'ブラウザでMCPドキュメントを確認してください:',
-  'or use the cli /docs command': 'または CLI の /docs コマンドを使用',
   '⏳ MCP servers are starting up ({{count}} initializing)...':
     '⏳ MCPサーバーを起動中({{count}} 初期化中)...',
   'Note: First startup may take longer. Tool availability will update automatically.':
@@ -883,4 +889,53 @@ export default {
     'コードが壊れた?叩けば治るさ',
     'USBの差し込みに挑戦中...',
   ],
+
+  // ============================================================================
+  // Custom API-KEY Configuration
+  // ============================================================================
+  'For advanced users who want to configure models manually.':
+    'モデルを手動で設定したい上級ユーザー向け。',
+  'Please configure your models in settings.json:':
+    'settings.json でモデルを設定してください：',
+  'Set API key via environment variable (e.g., OPENAI_API_KEY)':
+    '環境変数を使用して API キーを設定してください（例：OPENAI_API_KEY）',
+  "Add model configuration to modelProviders['openai'] (or other auth types)":
+    "modelProviders['openai']（または他の認証タイプ）にモデル設定を追加してください",
+  'Each provider needs: id, envKey (required), plus optional baseUrl, generationConfig':
+    '各プロバイダーには：id、envKey（必須）、およびオプションの baseUrl、generationConfig が必要です',
+  'Use /model command to select your preferred model from the configured list':
+    '/model コマンドを使用して、設定済みリストからお好みのモデルを選択してください',
+  'Supported auth types: openai, anthropic, gemini, vertex-ai, etc.':
+    'サポートされている認証タイプ：openai、anthropic、gemini、vertex-ai など',
+
+  // ============================================================================
+  // Coding Plan Authentication
+  // ============================================================================
+  'Please enter your API key:': 'APIキーを入力してください：',
+  'API key cannot be empty.': 'APIキーは空にできません。',
+  'You can get your exclusive Coding Plan API-KEY here:':
+    'Coding Plan の API-KEY はこちらで取得できます：',
+  'New model configurations are available for Bailian Coding Plan. Update now?':
+    'Bailian Coding Plan の新しいモデル設定が利用可能です。今すぐ更新しますか？',
+  'Coding Plan configuration updated successfully. New models are now available.':
+    'Coding Plan の設定が正常に更新されました。新しいモデルが利用可能になりました。',
+  'Coding Plan API key not found. Please re-authenticate with Coding Plan.':
+    'Coding Plan の API キーが見つかりません。Coding Plan で再認証してください。',
+  'Failed to update Coding Plan configuration: {{message}}':
+    'Coding Plan の設定更新に失敗しました: {{message}}',
+
+  // ============================================================================
+  // Auth Dialog - View Titles and Labels
+  // ============================================================================
+  'Coding Plan': 'Coding Plan',
+  "Paste your api key of Bailian Coding Plan and you're all set!":
+    'Bailian Coding PlanのAPIキーを貼り付けるだけで準備完了です！',
+  Custom: 'カスタム',
+  'More instructions about configuring `modelProviders` manually.':
+    '`modelProviders`を手動で設定する方法の詳細はこちら。',
+  'Select API-KEY configuration mode:': 'API-KEY設定モードを選択してください：',
+  '(Press Escape to go back)': '(Escapeキーで戻る)',
+  '(Press Enter to submit, Escape to cancel)':
+    '(Enterで送信、Escapeでキャンセル)',
+  'More instructions please check:': '詳細な手順はこちらをご確認ください：',
 };
