@@ -141,6 +141,8 @@ export default {
     'abrir documentação completa do Qwen Code no seu navegador',
   'Configuration not available.': 'Configuração não disponível.',
   'change the auth method': 'alterar o método de autenticação',
+  'Configure authentication information for login':
+    'Configurar informações de autenticação para login',
   'Copy the last result or code snippet to clipboard':
     'Copiar o último resultado ou trecho de código para a área de transferência',
 
@@ -365,7 +367,6 @@ export default {
   'Folder Trust': 'Confiança de Pasta',
   'Vision Model Preview': 'Visualização de Modelo de Visão',
   'Tool Schema Compliance': 'Conformidade de Esquema de Ferramenta',
-  'Experimental: Skills': 'Experimental: Habilidades',
 
   // Settings enum options
   'Auto (detect from system)': 'Automático (detectar do sistema)',
@@ -454,6 +455,8 @@ export default {
     'Esta extensão instalará os seguintes subagentes:',
   'Installation cancelled for "{{name}}".':
     'Instalação cancelada para "{{name}}".',
+  'You are installing an extension from {{originSource}}. Some features may not work perfectly with Qwen Code.':
+    'Você está instalando uma extensão de {{originSource}}. Alguns recursos podem não funcionar perfeitamente com o Qwen Code.',
   '--ref and --auto-update are not applicable for marketplace extensions.':
     '--ref e --auto-update não são aplicáveis para extensões de marketplace.',
   'Extension "{{name}}" installed successfully and enabled.':
@@ -957,6 +960,11 @@ export default {
   'Terms of Services and Privacy Notice for Qwen Code':
     'Termos de Serviço e Aviso de Privacidade do Qwen Code',
   'Qwen OAuth': 'Qwen OAuth',
+  'Login with QwenChat account to use daily free quota.':
+    'Faça login com sua conta QwenChat para usar a cota gratuita diária.',
+  'API-KEY': 'API-KEY',
+  'Use coding plan credentials or your own api-keys/providers.':
+    'Use credenciais do Coding Plan ou suas próprias chaves API/provedores.',
   OpenAI: 'OpenAI',
   'Failed to login. Message: {{message}}':
     'Falha ao fazer login. Mensagem: {{message}}',
@@ -1064,9 +1072,6 @@ export default {
   // MCP Status
   // ============================================================================
   'No MCP servers configured.': 'Nenhum servidor MCP configurado.',
-  'Please view MCP documentation in your browser:':
-    'Veja a documentação do MCP no seu navegador:',
-  'or use the cli /docs command': 'ou use o comando cli /docs',
   '⏳ MCP servers are starting up ({{count}} initializing)...':
     '⏳ Servidores MCP estão iniciando ({{count}} inicializando)...',
   'Note: First startup may take longer. Tool availability will update automatically.':
@@ -1387,4 +1392,54 @@ export default {
     'Abrindo página de extensões no seu navegador: {{url}}',
   'Failed to open browser. Check out the extensions gallery at {{url}}':
     'Falha ao abrir o navegador. Confira a galeria de extensões em {{url}}',
+
+  // ============================================================================
+  // Custom API-KEY Configuration
+  // ============================================================================
+  'For advanced users who want to configure models manually.':
+    'Para usuários avançados que desejam configurar modelos manualmente.',
+  'Please configure your models in settings.json:':
+    'Por favor, configure seus modelos em settings.json:',
+  'Set API key via environment variable (e.g., OPENAI_API_KEY)':
+    'Defina a chave de API via variável de ambiente (ex: OPENAI_API_KEY)',
+  "Add model configuration to modelProviders['openai'] (or other auth types)":
+    "Adicione a configuração do modelo a modelProviders['openai'] (ou outros tipos de autenticação)",
+  'Each provider needs: id, envKey (required), plus optional baseUrl, generationConfig':
+    'Cada provedor precisa de: id, envKey (obrigatório), além de baseUrl e generationConfig opcionais',
+  'Use /model command to select your preferred model from the configured list':
+    'Use o comando /model para selecionar seu modelo preferido da lista configurada',
+  'Supported auth types: openai, anthropic, gemini, vertex-ai, etc.':
+    'Tipos de autenticação suportados: openai, anthropic, gemini, vertex-ai, etc.',
+
+  // ============================================================================
+  // Coding Plan Authentication
+  // ============================================================================
+  'Please enter your API key:': 'Por favor, digite sua chave de API:',
+  'API key cannot be empty.': 'A chave de API não pode estar vazia.',
+  'You can get your exclusive Coding Plan API-KEY here:':
+    'Você pode obter sua chave de API exclusiva do Coding Plan aqui:',
+  'New model configurations are available for Bailian Coding Plan. Update now?':
+    'Novas configurações de modelo estão disponíveis para o Bailian Coding Plan. Atualizar agora?',
+  'Coding Plan configuration updated successfully. New models are now available.':
+    'Configuração do Coding Plan atualizada com sucesso. Novos modelos agora estão disponíveis.',
+  'Coding Plan API key not found. Please re-authenticate with Coding Plan.':
+    'Chave de API do Coding Plan não encontrada. Por favor, re-autentique com o Coding Plan.',
+  'Failed to update Coding Plan configuration: {{message}}':
+    'Falha ao atualizar a configuração do Coding Plan: {{message}}',
+
+  // ============================================================================
+  // Auth Dialog - View Titles and Labels
+  // ============================================================================
+  'Coding Plan': 'Coding Plan',
+  "Paste your api key of Bailian Coding Plan and you're all set!":
+    'Cole sua chave de API do Bailian Coding Plan e pronto!',
+  Custom: 'Personalizado',
+  'More instructions about configuring `modelProviders` manually.':
+    'Mais instruções sobre como configurar `modelProviders` manualmente.',
+  'Select API-KEY configuration mode:':
+    'Selecione o modo de configuração da API-KEY:',
+  '(Press Escape to go back)': '(Pressione Escape para voltar)',
+  '(Press Enter to submit, Escape to cancel)':
+    '(Pressione Enter para enviar, Escape para cancelar)',
+  'More instructions please check:': 'Mais instruções, consulte:',
 };
